@@ -23,6 +23,7 @@ namespace Sonnet
 class Speller;
 
 /**
+ * @class Sonnet::BackgroundChecker backgroundchecker.h <Sonnet/BackgroundChecker>
  *
  * BackgroundChecker is used to perform spell checking without
  * blocking the application. You can use it as is by calling
@@ -45,7 +46,7 @@ class SONNETCORE_EXPORT BackgroundChecker : public QObject
 public:
     explicit BackgroundChecker(QObject *parent = nullptr);
     explicit BackgroundChecker(const Speller &speller, QObject *parent = nullptr);
-    ~BackgroundChecker();
+    ~BackgroundChecker() override;
 
     /**
      * This method is used to spell check static text.
@@ -121,7 +122,7 @@ protected:
      * This function is called to get the text to spell check.
      * It will be called continuesly until it returns QString()
      * in which case the done() signal is emitted.
-     * Note: the start parameter in mispelling() is not a combined
+     * Note: the start parameter in misspelling() is not a combined
      * position but a position in the last string returned
      * by fetchMoreText. You need to store the state in the derivatives.
      */
