@@ -736,7 +736,12 @@ QStringList GuessLanguagePrivate::guessFromTrigrams(const QString &sample, const
 
     int counter = 0;
     double confidence = 0;
+
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+    QMultiMapIterator<int, QString> it(scores);
+#else
     QMapIterator<int, QString> it(scores);
+#endif
     it.next();
 
     QString prevItem = it.value();
@@ -843,7 +848,7 @@ QString GuessLanguagePrivate::guessFromDictionaries(const QString &sentence, con
 
     WordTokenizer tokenizer(sentence);
     while (tokenizer.hasNext()) {
-        QStringRef word = tokenizer.next();
+        Token word = tokenizer.next();
         if (!tokenizer.isSpellcheckable()) {
             continue;
         }
