@@ -83,8 +83,8 @@ SpellerPlugin *Loader::createSpeller(const QString &language, const QString &cli
 
     auto clientsItr = d->languageClients.constFind(plang);
     if (clientsItr == d->languageClients.constEnd()) {
-        if (language.isEmpty()) {
-            qCWarning(SONNET_LOG_CORE) << "No language dictionaries for the language:" << plang << "trying to load en_US as default";
+        if (language.isEmpty() || language == QStringLiteral("C")) {
+            qCDebug(SONNET_LOG_CORE) << "No language dictionaries for the language:" << plang << "trying to load en_US as default";
             return createSpeller(QStringLiteral("en_US"), clientName);
         }
         qCWarning(SONNET_LOG_CORE) << "No language dictionaries for the language:" << plang;
@@ -298,10 +298,6 @@ void Loader::loadPlugin(const QString &pluginPath)
 {
 #ifndef SONNET_STATIC
     QPluginLoader plugin(pluginPath);
-    if (!plugin.load()) { // We do this separately for better error handling
-        qCWarning(SONNET_LOG_CORE) << "Sonnet: Unable to load plugin" << pluginPath << "Error:" << plugin.errorString();
-        return;
-    }
     const QString pluginIID = plugin.metaData()[QStringLiteral("IID")].toString();
     if (!pluginIID.isEmpty()) {
         if (d->loadedPlugins.contains(pluginIID)) {
@@ -311,6 +307,12 @@ void Loader::loadPlugin(const QString &pluginPath)
         d->loadedPlugins.insert(pluginIID);
     }
 
+    if (!plugin.load()) { // We do this separately for better error handling
+        qCDebug(SONNET_LOG_CORE) << "Sonnet: Unable to load plugin" << pluginPath << "Error:" << plugin.errorString();
+        d->loadedPlugins.remove(pluginIID);
+        return;
+    }
+
     Client *client = qobject_cast<Client *>(plugin.instance());
     if (!client) {
         qCWarning(SONNET_LOG_CORE) << "Sonnet: Invalid plugin loaded" << pluginPath;
