@@ -12,14 +12,15 @@
 class ConfigDialogPrivate;
 #include "sonnetui_export.h"
 
-namespace Sonnet {
+namespace Sonnet
+{
 /// The sonnet ConfigDialog
 class SONNETUI_EXPORT ConfigDialog : public QDialog
 {
     Q_OBJECT
 public:
     explicit ConfigDialog(QWidget *parent);
-    ~ConfigDialog();
+    ~ConfigDialog() override;
 
     /**
      * Sets the language/dictionary that will be selected by default
