@@ -13,14 +13,15 @@
 // Qt
 #include <QContextMenuEvent>
 #include <QMenu>
-#include <QTextEdit>
 #include <QPlainTextEdit>
+#include <QTextEdit>
 
-namespace Sonnet {
-class Q_DECL_HIDDEN SpellCheckDecorator::Private
+namespace Sonnet
+{
+class SpellCheckDecoratorPrivate
 {
 public:
-    Private(SpellCheckDecorator *installer, QPlainTextEdit *textEdit)
+    SpellCheckDecoratorPrivate(SpellCheckDecorator *installer, QPlainTextEdit *textEdit)
         : q(installer)
         , m_plainTextEdit(textEdit)
     {
@@ -31,7 +32,7 @@ public:
         m_plainTextEdit->viewport()->installEventFilter(q);
     }
 
-    Private(SpellCheckDecorator *installer, QTextEdit *textEdit)
+    SpellCheckDecoratorPrivate(SpellCheckDecorator *installer, QTextEdit *textEdit)
         : q(installer)
         , m_textEdit(textEdit)
     {
@@ -42,17 +43,29 @@ public:
         m_textEdit->viewport()->installEventFilter(q);
     }
 
+    ~SpellCheckDecoratorPrivate()
+    {
+        if (m_plainTextEdit) {
+            m_plainTextEdit->removeEventFilter(q);
+            m_plainTextEdit->removeEventFilter(q);
+        }
+        if (m_textEdit) {
+            m_textEdit->removeEventFilter(q);
+            m_textEdit->viewport()->removeEventFilter(q);
+        }
+    }
+
     bool onContextMenuEvent(QContextMenuEvent *event);
     void execSuggestionMenu(const QPoint &pos, const QString &word, const QTextCursor &cursor);
     void createDefaultHighlighter();
 
-    SpellCheckDecorator *q = nullptr;
+    SpellCheckDecorator *const q;
     QTextEdit *m_textEdit = nullptr;
     QPlainTextEdit *m_plainTextEdit = nullptr;
     Highlighter *m_highlighter = nullptr;
 };
 
-bool SpellCheckDecorator::Private::onContextMenuEvent(QContextMenuEvent *event)
+bool SpellCheckDecoratorPrivate::onContextMenuEvent(QContextMenuEvent *event)
 {
     if (!m_highlighter) {
         createDefaultHighlighter();
@@ -74,9 +87,11 @@ bool SpellCheckDecorator::Private::onContextMenuEvent(QContextMenuEvent *event)
     }
 
     // Check if the user clicked a selected word
+    /* clang-format off */
     const bool selectedWordClicked = cursor.hasSelection()
                                      && mousePos >= cursor.selectionStart()
                                      && mousePos <= cursor.selectionEnd();
+    /* clang-format on */
 
     // Get the word under the (mouse-)cursor and see if it is misspelled.
     // Don't include apostrophes at the start/end of the word in the selection.
@@ -86,8 +101,7 @@ bool SpellCheckDecorator::Private::onContextMenuEvent(QContextMenuEvent *event)
     QString selectedWord = wordSelectCursor.selectedText();
 
     bool isMouseCursorInsideWord = true;
-    if ((mousePos < wordSelectCursor.selectionStart()
-         || mousePos >= wordSelectCursor.selectionEnd())
+    if ((mousePos < wordSelectCursor.selectionStart() || mousePos >= wordSelectCursor.selectionEnd()) //
         && (selectedWord.length() > 1)) {
         isMouseCursorInsideWord = false;
     }
@@ -102,14 +116,15 @@ bool SpellCheckDecorator::Private::onContextMenuEvent(QContextMenuEvent *event)
         selectedWord.chop(1);
     }
 
-    wordSelectCursor.movePosition(QTextCursor::NextCharacter,
-                                  QTextCursor::KeepAnchor, selectedWord.size());
+    wordSelectCursor.movePosition(QTextCursor::NextCharacter, QTextCursor::KeepAnchor, selectedWord.size());
 
+    /* clang-format off */
     const bool wordIsMisspelled = isMouseCursorInsideWord
                                   && m_highlighter
                                   && m_highlighter->isActive()
                                   && !selectedWord.isEmpty()
                                   && m_highlighter->isWordMisspelled(selectedWord);
+    /* clang-format on */
 
     // If the user clicked a selected word, do nothing.
     // If the user clicked somewhere else, move the cursor there.
@@ -146,17 +161,15 @@ bool SpellCheckDecorator::Private::onContextMenuEvent(QContextMenuEvent *event)
     return true;
 }
 
-void SpellCheckDecorator::Private::execSuggestionMenu(const QPoint &pos,
-                                                      const QString &selectedWord,
-                                                      const QTextCursor &_cursor)
+void SpellCheckDecoratorPrivate::execSuggestionMenu(const QPoint &pos, const QString &selectedWord, const QTextCursor &_cursor)
 {
     QTextCursor cursor = _cursor;
-    QMenu menu; //don't use KMenu here we don't want auto management accelerator
+    QMenu menu; // don't use KMenu here we don't want auto management accelerator
 
-    //Add the suggestions to the menu
+    // Add the suggestions to the menu
     const QStringList reps = m_highlighter->suggestionsForWord(selectedWord, cursor);
     if (reps.isEmpty()) {
-        QAction *suggestionsAction = menu.addAction(tr("No suggestions for %1").arg(selectedWord));
+        QAction *suggestionsAction = menu.addAction(SpellCheckDecorator::tr("No suggestions for %1").arg(selectedWord));
         suggestionsAction->setEnabled(false);
     } else {
         QStringList::const_iterator end(reps.constEnd());
@@ -167,13 +180,14 @@ void SpellCheckDecorator::Private::execSuggestionMenu(const QPoint &pos,
 
     menu.addSeparator();
 
-    QAction *ignoreAction = menu.addAction(tr("Ignore"));
-    QAction *addToDictAction = menu.addAction(tr("Add to Dictionary"));
-    //Execute the popup inline
+    QAction *ignoreAction = menu.addAction(SpellCheckDecorator::tr("Ignore"));
+    QAction *addToDictAction = menu.addAction(SpellCheckDecorator::tr("Add to Dictionary"));
+    // Execute the popup inline
     const QAction *selectedAction = menu.exec(pos);
 
     if (selectedAction) {
-        Q_ASSERT(cursor.selectedText() == selectedWord);
+        // Fails when we're in the middle of a compose-key sequence
+        // Q_ASSERT(cursor.selectedText() == selectedWord);
 
         if (selectedAction == ignoreAction) {
             m_highlighter->ignoreWord(selectedWord);
@@ -196,7 +210,7 @@ void SpellCheckDecorator::Private::execSuggestionMenu(const QPoint &pos,
     }
 }
 
-void SpellCheckDecorator::Private::createDefaultHighlighter()
+void SpellCheckDecoratorPrivate::createDefaultHighlighter()
 {
     if (m_textEdit) {
         m_highlighter = new Highlighter(m_textEdit);
@@ -207,20 +221,17 @@ void SpellCheckDecorator::Private::createDefaultHighlighter()
 
 SpellCheckDecorator::SpellCheckDecorator(QTextEdit *textEdit)
     : QObject(textEdit)
-    , d(new Private(this, textEdit))
+    , d(std::make_unique<SpellCheckDecoratorPrivate>(this, textEdit))
 {
 }
 
 SpellCheckDecorator::SpellCheckDecorator(QPlainTextEdit *textEdit)
     : QObject(textEdit)
-    , d(new Private(this, textEdit))
+    , d(std::make_unique<SpellCheckDecoratorPrivate>(this, textEdit))
 {
 }
 
-SpellCheckDecorator::~SpellCheckDecorator()
-{
-    delete d;
-}
+SpellCheckDecorator::~SpellCheckDecorator() = default;
 
 void SpellCheckDecorator::setHighlighter(Highlighter *highlighter)
 {
