@@ -13,9 +13,8 @@ using namespace Sonnet;
 #include <QApplication>
 #include <QDebug>
 
-const char *text
-    =
-        "Rationale \
+const char *text =
+    "Rationale \
 ========= \
  \
 This code is intended to provide an implementation of the W3C's XPath \
@@ -61,7 +60,7 @@ This is the most obvious library to reuse as it is currently used to generate\
 the KDE documentation, and is also a very complete and fast\
 implementation. The down side of using this code is that it would either need\
 "
-        "a new DOM implementation in KHTML (which used the libxml2 structures), a \
+    "a new DOM implementation in KHTML (which used the libxml2 structures), a \
 wrapper library that made on of the DOM trees support the API of the other, or\
 binding layer that parsed the XML twice and somehow maintained a mapping\
 between the two DOM trees. Unfortunately the documentation of this library is\
@@ -124,10 +123,8 @@ BackgroundTest::BackgroundTest()
     , m_speller("en")
 {
     m_checker = new BackgroundChecker(m_speller, this);
-    connect(m_checker, SIGNAL(done()),
-            SLOT(slotDone()));
-    connect(m_checker, SIGNAL(misspelling(QString,int)),
-            SLOT(slotMisspelling(QString,int)));
+    connect(m_checker, SIGNAL(done()), SLOT(slotDone()));
+    connect(m_checker, SIGNAL(misspelling(QString, int)), SLOT(slotMisspelling(QString, int)));
     m_len = strlen(text);
     m_checker->setText(text);
     m_checker->speller().setLanguage("en");
